Developer's guide
=================

Adapting dhcpkit to your needs might require some custom development. There are several areas where you can customise
the server's behaviour:

.. toctree::

    option
    handler


If you are developing software to work with DHCPKit you probably want to know all the modules, classes and functions
you can use. Below is a complete list of everything in the package:

.. toctree::

    API <../api/dhcpkit>
